==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/KuryrConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class KuryrConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.KuryrConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.KuryrConfigFluent<A>{
  public KuryrConfigFluentImpl() {
  }
  public KuryrConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.KuryrConfig instance) {
    this.withControllerProbesPort(instance.getControllerProbesPort()); 
    this.withDaemonProbesPort(instance.getDaemonProbesPort()); 
    this.withEnablePortPoolsPrepopulation(instance.getEnablePortPoolsPrepopulation()); 
    this.withMtu(instance.getMtu()); 
    this.withOpenStackServiceNetwork(instance.getOpenStackServiceNetwork()); 
    this.withPoolBatchPorts(instance.getPoolBatchPorts()); 
    this.withPoolMaxPorts(instance.getPoolMaxPorts()); 
    this.withPoolMinPorts(instance.getPoolMinPorts()); 
  }
  private java.lang.Integer controllerProbesPort;
  private java.lang.Integer daemonProbesPort;
  private java.lang.Boolean enablePortPoolsPrepopulation;
  private java.lang.Integer mtu;
  private java.lang.String openStackServiceNetwork;
  private java.lang.Integer poolBatchPorts;
  private java.lang.Integer poolMaxPorts;
  private java.lang.Integer poolMinPorts;
  public java.lang.Integer getControllerProbesPort() {
    return this.controllerProbesPort;
  }
  public A withControllerProbesPort(java.lang.Integer controllerProbesPort) {
    this.controllerProbesPort=controllerProbesPort; return (A) this;
  }
  public java.lang.Boolean hasControllerProbesPort() {
    return this.controllerProbesPort != null;
  }
  public java.lang.Integer getDaemonProbesPort() {
    return this.daemonProbesPort;
  }
  public A withDaemonProbesPort(java.lang.Integer daemonProbesPort) {
    this.daemonProbesPort=daemonProbesPort; return (A) this;
  }
  public java.lang.Boolean hasDaemonProbesPort() {
    return this.daemonProbesPort != null;
  }
  public java.lang.Boolean getEnablePortPoolsPrepopulation() {
    return this.enablePortPoolsPrepopulation;
  }
  public A withEnablePortPoolsPrepopulation(java.lang.Boolean enablePortPoolsPrepopulation) {
    this.enablePortPoolsPrepopulation=enablePortPoolsPrepopulation; return (A) this;
  }
  public java.lang.Boolean hasEnablePortPoolsPrepopulation() {
    return this.enablePortPoolsPrepopulation != null;
  }
  public java.lang.Integer getMtu() {
    return this.mtu;
  }
  public A withMtu(java.lang.Integer mtu) {
    this.mtu=mtu; return (A) this;
  }
  public java.lang.Boolean hasMtu() {
    return this.mtu != null;
  }
  public java.lang.String getOpenStackServiceNetwork() {
    return this.openStackServiceNetwork;
  }
  public A withOpenStackServiceNetwork(java.lang.String openStackServiceNetwork) {
    this.openStackServiceNetwork=openStackServiceNetwork; return (A) this;
  }
  public java.lang.Boolean hasOpenStackServiceNetwork() {
    return this.openStackServiceNetwork != null;
  }
  
  /**
   * Method is deprecated. use withOpenStackServiceNetwork instead.
   */
  @java.lang.Deprecated
  public A withNewOpenStackServiceNetwork(java.lang.String arg0) {
    return (A)withOpenStackServiceNetwork(new String(arg0));
  }
  public java.lang.Integer getPoolBatchPorts() {
    return this.poolBatchPorts;
  }
  public A withPoolBatchPorts(java.lang.Integer poolBatchPorts) {
    this.poolBatchPorts=poolBatchPorts; return (A) this;
  }
  public java.lang.Boolean hasPoolBatchPorts() {
    return this.poolBatchPorts != null;
  }
  public java.lang.Integer getPoolMaxPorts() {
    return this.poolMaxPorts;
  }
  public A withPoolMaxPorts(java.lang.Integer poolMaxPorts) {
    this.poolMaxPorts=poolMaxPorts; return (A) this;
  }
  public java.lang.Boolean hasPoolMaxPorts() {
    return this.poolMaxPorts != null;
  }
  public java.lang.Integer getPoolMinPorts() {
    return this.poolMinPorts;
  }
  public A withPoolMinPorts(java.lang.Integer poolMinPorts) {
    this.poolMinPorts=poolMinPorts; return (A) this;
  }
  public java.lang.Boolean hasPoolMinPorts() {
    return this.poolMinPorts != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KuryrConfigFluentImpl that = (KuryrConfigFluentImpl) o;
    if (controllerProbesPort != null ? !controllerProbesPort.equals(that.controllerProbesPort) :that.controllerProbesPort != null) return false;
    if (daemonProbesPort != null ? !daemonProbesPort.equals(that.daemonProbesPort) :that.daemonProbesPort != null) return false;
    if (enablePortPoolsPrepopulation != null ? !enablePortPoolsPrepopulation.equals(that.enablePortPoolsPrepopulation) :that.enablePortPoolsPrepopulation != null) return false;
    if (mtu != null ? !mtu.equals(that.mtu) :that.mtu != null) return false;
    if (openStackServiceNetwork != null ? !openStackServiceNetwork.equals(that.openStackServiceNetwork) :that.openStackServiceNetwork != null) return false;
    if (poolBatchPorts != null ? !poolBatchPorts.equals(that.poolBatchPorts) :that.poolBatchPorts != null) return false;
    if (poolMaxPorts != null ? !poolMaxPorts.equals(that.poolMaxPorts) :that.poolMaxPorts != null) return false;
    if (poolMinPorts != null ? !poolMinPorts.equals(that.poolMinPorts) :that.poolMinPorts != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(controllerProbesPort,  daemonProbesPort,  enablePortPoolsPrepopulation,  mtu,  openStackServiceNetwork,  poolBatchPorts,  poolMaxPorts,  poolMinPorts,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KuryrConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class KuryrConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.KuryrConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.KuryrConfigFluent<A>{
  public KuryrConfigFluentImpl() {
  }
  public KuryrConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.KuryrConfig instance) {
    this.withControllerProbesPort(instance.getControllerProbesPort()); 
    this.withDaemonProbesPort(instance.getDaemonProbesPort()); 
    this.withEnablePortPoolsPrepopulation(instance.getEnablePortPoolsPrepopulation()); 
    this.withMtu(instance.getMtu()); 
    this.withOpenStackServiceNetwork(instance.getOpenStackServiceNetwork()); 
    this.withPoolBatchPorts(instance.getPoolBatchPorts()); 
    this.withPoolMaxPorts(instance.getPoolMaxPorts()); 
    this.withPoolMinPorts(instance.getPoolMinPorts()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Integer controllerProbesPort;
  private java.lang.Integer daemonProbesPort;
  private java.lang.Boolean enablePortPoolsPrepopulation;
  private java.lang.Integer mtu;
  private java.lang.String openStackServiceNetwork;
  private java.lang.Integer poolBatchPorts;
  private java.lang.Integer poolMaxPorts;
  private java.lang.Integer poolMinPorts;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Integer getControllerProbesPort() {
    return this.controllerProbesPort;
  }
  public A withControllerProbesPort(java.lang.Integer controllerProbesPort) {
    this.controllerProbesPort=controllerProbesPort; return (A) this;
  }
  public java.lang.Boolean hasControllerProbesPort() {
    return this.controllerProbesPort != null;
  }
  public java.lang.Integer getDaemonProbesPort() {
    return this.daemonProbesPort;
  }
  public A withDaemonProbesPort(java.lang.Integer daemonProbesPort) {
    this.daemonProbesPort=daemonProbesPort; return (A) this;
  }
  public java.lang.Boolean hasDaemonProbesPort() {
    return this.daemonProbesPort != null;
  }
  public java.lang.Boolean getEnablePortPoolsPrepopulation() {
    return this.enablePortPoolsPrepopulation;
  }
  public A withEnablePortPoolsPrepopulation(java.lang.Boolean enablePortPoolsPrepopulation) {
    this.enablePortPoolsPrepopulation=enablePortPoolsPrepopulation; return (A) this;
  }
  public java.lang.Boolean hasEnablePortPoolsPrepopulation() {
    return this.enablePortPoolsPrepopulation != null;
  }
  public java.lang.Integer getMtu() {
    return this.mtu;
  }
  public A withMtu(java.lang.Integer mtu) {
    this.mtu=mtu; return (A) this;
  }
  public java.lang.Boolean hasMtu() {
    return this.mtu != null;
  }
  public java.lang.String getOpenStackServiceNetwork() {
    return this.openStackServiceNetwork;
  }
  public A withOpenStackServiceNetwork(java.lang.String openStackServiceNetwork) {
    this.openStackServiceNetwork=openStackServiceNetwork; return (A) this;
  }
  public java.lang.Boolean hasOpenStackServiceNetwork() {
    return this.openStackServiceNetwork != null;
  }
  
  /**
   * Method is deprecated. use withOpenStackServiceNetwork instead.
   */
  @java.lang.Deprecated
  public A withNewOpenStackServiceNetwork(java.lang.String arg0) {
    return (A)withOpenStackServiceNetwork(new String(arg0));
  }
  public java.lang.Integer getPoolBatchPorts() {
    return this.poolBatchPorts;
  }
  public A withPoolBatchPorts(java.lang.Integer poolBatchPorts) {
    this.poolBatchPorts=poolBatchPorts; return (A) this;
  }
  public java.lang.Boolean hasPoolBatchPorts() {
    return this.poolBatchPorts != null;
  }
  public java.lang.Integer getPoolMaxPorts() {
    return this.poolMaxPorts;
  }
  public A withPoolMaxPorts(java.lang.Integer poolMaxPorts) {
    this.poolMaxPorts=poolMaxPorts; return (A) this;
  }
  public java.lang.Boolean hasPoolMaxPorts() {
    return this.poolMaxPorts != null;
  }
  public java.lang.Integer getPoolMinPorts() {
    return this.poolMinPorts;
  }
  public A withPoolMinPorts(java.lang.Integer poolMinPorts) {
    this.poolMinPorts=poolMinPorts; return (A) this;
  }
  public java.lang.Boolean hasPoolMinPorts() {
    return this.poolMinPorts != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KuryrConfigFluentImpl that = (KuryrConfigFluentImpl) o;
    if (controllerProbesPort != null ? !controllerProbesPort.equals(that.controllerProbesPort) :that.controllerProbesPort != null) return false;
    if (daemonProbesPort != null ? !daemonProbesPort.equals(that.daemonProbesPort) :that.daemonProbesPort != null) return false;
    if (enablePortPoolsPrepopulation != null ? !enablePortPoolsPrepopulation.equals(that.enablePortPoolsPrepopulation) :that.enablePortPoolsPrepopulation != null) return false;
    if (mtu != null ? !mtu.equals(that.mtu) :that.mtu != null) return false;
    if (openStackServiceNetwork != null ? !openStackServiceNetwork.equals(that.openStackServiceNetwork) :that.openStackServiceNetwork != null) return false;
    if (poolBatchPorts != null ? !poolBatchPorts.equals(that.poolBatchPorts) :that.poolBatchPorts != null) return false;
    if (poolMaxPorts != null ? !poolMaxPorts.equals(that.poolMaxPorts) :that.poolMaxPorts != null) return false;
    if (poolMinPorts != null ? !poolMinPorts.equals(that.poolMinPorts) :that.poolMinPorts != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(controllerProbesPort,  daemonProbesPort,  enablePortPoolsPrepopulation,  mtu,  openStackServiceNetwork,  poolBatchPorts,  poolMaxPorts,  poolMinPorts,  additionalProperties,  super.hashCode());
  }
  
}
